@@ -66,6 +66,8 @@ struct _TangleActorPrivate {
 
 	ClutterActorBox aligned_allocation;
 	gdouble interactive_size_multiplier;
+	
+	ClutterActorBox layout_allocation;
 
 	TangleAction* button_press_action;
 	TangleAction* button_release_action;
@@ -801,6 +803,14 @@ void tangle_actor_set_interactive_size_multiplier_set(TangleActor* actor, gboole
 	}
 }
 
+void tangle_actor_get_layout_allocation(TangleActor* actor, ClutterActorBox* actor_box) {
+	*actor_box = actor->priv->layout_allocation;
+}
+
+void tangle_actor_set_layout_allocation(TangleActor* actor, const ClutterActorBox* actor_box) {
+	actor->priv->layout_allocation = *actor_box;
+}
+
 GType tangle_spacing_get_type(void) {
 	static GType type = 0;
 
