@@ -138,6 +138,9 @@ void tangle_actor_set_interactive_size_multiplier(TangleActor* actor, gdouble mu
 gboolean tangle_actor_get_interactive_size_multiplier_set(TangleActor* actor);
 void tangle_actor_set_interactive_size_multiplier_set(TangleActor* actor, gboolean is_set);
 
+void tangle_actor_get_layout_allocation(TangleActor* actor, ClutterActorBox* actor_box);
+void tangle_actor_set_layout_allocation(TangleActor* actor, const ClutterActorBox* actor_box);
+
 #define TANGLE_TYPE_SPACING (tangle_spacing_get_type())
 #define TANGLE_SPACING(s) ((TangleSpacing*)(s))
 
