@@ -143,11 +143,9 @@ void tangle_button_set_normal_background_actor(TangleButton* button, ClutterActo
 	if (button->priv->normal_background_actor != actor) {
 		if (button->priv->normal_background_actor) {
 			clutter_actor_unparent(button->priv->normal_background_actor);
-			g_object_unref(button->priv->normal_background_actor);
 		}
 		button->priv->normal_background_actor = actor;
 		if (button->priv->normal_background_actor) {
-			g_object_ref_sink(button->priv->normal_background_actor);
 			clutter_actor_push_internal(CLUTTER_ACTOR(button));
 			clutter_actor_set_parent(button->priv->normal_background_actor, CLUTTER_ACTOR(button));	
 			clutter_actor_pop_internal(CLUTTER_ACTOR(button));
@@ -173,12 +171,10 @@ void tangle_button_set_interactive_background_actor(TangleButton* button, Clutte
 	if (button->priv->interactive_background_actor != actor) {
 		if (button->priv->interactive_background_actor) {
 			clutter_actor_unparent(button->priv->interactive_background_actor);
-			g_object_unref(button->priv->interactive_background_actor);
 			had_interactive_background_actor = TRUE;
 		}
 		button->priv->interactive_background_actor = actor;
 		if (button->priv->interactive_background_actor) {
-			g_object_ref_sink(button->priv->interactive_background_actor);
 			clutter_actor_push_internal(CLUTTER_ACTOR(button));
 			clutter_actor_set_parent(button->priv->interactive_background_actor, CLUTTER_ACTOR(button));	
 			clutter_actor_pop_internal(CLUTTER_ACTOR(button));
@@ -208,12 +204,10 @@ void tangle_button_set_selected_background_actor(TangleButton* button, ClutterAc
 	if (button->priv->selected_background_actor != actor) {
 		if (button->priv->selected_background_actor) {
 			clutter_actor_unparent(button->priv->selected_background_actor);
-			g_object_unref(button->priv->selected_background_actor);
 			had_selected_background_actor = TRUE;
 		}
 		button->priv->selected_background_actor = actor;
 		if (button->priv->selected_background_actor) {
-			g_object_ref_sink(button->priv->selected_background_actor);
 			clutter_actor_push_internal(CLUTTER_ACTOR(button));
 			clutter_actor_set_parent(button->priv->selected_background_actor, CLUTTER_ACTOR(button));	
 			clutter_actor_pop_internal(CLUTTER_ACTOR(button));
@@ -256,17 +250,6 @@ void tangle_button_set_selected(TangleButton* button, gboolean selected) {
 	}
 }
 
-static void tangle_button_handle_ancestor_event(TangleActor* actor, TangleEvent* event) {
-	if (event->any.sender != actor) {
-		if (event->type == TANGLE_EVENT_INTERACTION_BEGAN) {
-			end_interacting(TANGLE_BUTTON(actor));
-			TANGLE_BUTTON(actor)->priv->active = FALSE;
-		}
-	}
-
-	TANGLE_ACTOR_CLASS(tangle_button_parent_class)->handle_ancestor_event(actor, event);	
-}
-
 static gboolean tangle_button_clicked(TangleButton* button) {
 	TangleProperties* properties;
 	
@@ -297,6 +280,24 @@ static void tangle_button_map(ClutterActor* actor) {
 	}
 }
 
+static void tangle_button_unmap(ClutterActor* actor) {
+	TangleButton* button;
+
+	button = TANGLE_BUTTON(actor);
+
+	if (button->priv->normal_background_actor) {
+		clutter_actor_unmap(button->priv->normal_background_actor);
+	}
+	if (button->priv->interactive_background_actor) {
+		clutter_actor_unmap(button->priv->interactive_background_actor);
+	}
+	if (button->priv->selected_background_actor) {
+		clutter_actor_unmap(button->priv->selected_background_actor);
+	}
+
+	CLUTTER_ACTOR_CLASS(tangle_button_parent_class)->unmap(actor);
+}
+
 static void tangle_button_set_property(GObject* object, guint prop_id, const GValue* value, GParamSpec* pspec) {
 	TangleButton* button;
 	
@@ -366,9 +367,9 @@ static void tangle_button_dispose(GObject* object) {
 	
 	button = TANGLE_BUTTON(object);
 	
-	TANGLE_UNREF_AND_NULLIFY_OBJECT(button->priv->normal_background_actor);
-	TANGLE_UNREF_AND_NULLIFY_OBJECT(button->priv->interactive_background_actor);
-	TANGLE_UNREF_AND_NULLIFY_OBJECT(button->priv->selected_background_actor);
+	TANGLE_UNPARENT_AND_NULLIFY_ACTOR(button->priv->normal_background_actor);
+	TANGLE_UNPARENT_AND_NULLIFY_ACTOR(button->priv->interactive_background_actor);
+	TANGLE_UNPARENT_AND_NULLIFY_ACTOR(button->priv->selected_background_actor);
 	TANGLE_UNREF_AND_NULLIFY_OBJECT(button->priv->clicked_action);
 	
 	if (button->priv->button_release_event_handler_actor) {
@@ -389,8 +390,7 @@ static void tangle_button_class_init(TangleButtonClass* button_class) {
 	gobject_class->get_property = tangle_button_get_property;
 
 	clutter_actor_class->map = tangle_button_map;
-
-	actor_class->handle_ancestor_event = tangle_button_handle_ancestor_event;
+	clutter_actor_class->unmap = tangle_button_unmap;
 
 	button_class->clicked = tangle_button_clicked;
 
@@ -465,10 +465,7 @@ static void tangle_button_class_init(TangleButtonClass* button_class) {
 }
 
 static void start_interacting(TangleButton* button) {
-	TangleEvent* event;
-
 	tangle_actor_set_interacting(TANGLE_ACTOR(button), TRUE);
-	tangle_actor_send_interaction_began_event(TANGLE_ACTOR(button), TRUE, TRUE, FALSE);
 	if (button->priv->interactive_background_actor) {
 		tangle_widget_change_background_actor(TANGLE_WIDGET(button), button->priv->interactive_background_actor);
 	}
@@ -477,21 +474,18 @@ static void start_interacting(TangleButton* button) {
 	g_object_add_weak_pointer(G_OBJECT(button->priv->button_release_event_handler_actor), (gpointer*)&button->priv->button_release_event_handler_actor);
 	g_signal_connect(button->priv->button_release_event_handler_actor, "button-release-event", G_CALLBACK(on_button_release_event), button);
 
-	tangle_actor_send_interaction_began_event(TANGLE_ACTOR(button), TRUE, TRUE, FALSE);
+	tangle_actor_set_interacting(TANGLE_ACTOR(button), TRUE);
 }
 
 static void end_interacting(TangleButton* button) {
-	TangleEvent* event;
-	
 	tangle_actor_set_interacting(TANGLE_ACTOR(button), FALSE);
-	tangle_actor_send_interaction_ended_event(TANGLE_ACTOR(button), TRUE, TRUE, FALSE);
 	if ((button->priv->mode == TANGLE_BUTTON_SELECTABLE || button->priv->mode == TANGLE_BUTTON_RADIO) && button->priv->selected && button->priv->selected_background_actor) {
 		tangle_widget_change_background_actor(TANGLE_WIDGET(button), button->priv->selected_background_actor);
 	} else {
 		tangle_widget_change_background_actor(TANGLE_WIDGET(button), button->priv->normal_background_actor);
 	}
 
-	tangle_actor_send_interaction_ended_event(TANGLE_ACTOR(button), TRUE, TRUE, FALSE);
+	tangle_actor_set_interacting(TANGLE_ACTOR(button), FALSE);
 }
 
 static gboolean on_button_release_event(ClutterActor* actor, ClutterEvent* event, gpointer user_data) {
@@ -552,10 +546,22 @@ static gboolean on_leave_event(ClutterActor* actor, ClutterEvent* event, gpointe
 
 }
 
+static void on_notify_ancestor_interacting(GObject* object, GParamSpec* param_spec, gpointer user_data) {
+	TangleButton* button;
+	
+	button = TANGLE_BUTTON(object);
+
+	if (tangle_actor_get_ancestor_interacting(TANGLE_ACTOR(button))) {
+		end_interacting(button);
+		button->priv->active = FALSE;
+	}
+}
+
 static void tangle_button_init(TangleButton* button) {
 	button->priv = G_TYPE_INSTANCE_GET_PRIVATE(button, TANGLE_TYPE_BUTTON, TangleButtonPrivate);
 	clutter_actor_set_reactive(CLUTTER_ACTOR(button), TRUE);
 	g_signal_connect(button, "button-press-event", G_CALLBACK(on_button_press_event), NULL);
 	g_signal_connect(button, "enter-event", G_CALLBACK(on_enter_event), NULL);
 	g_signal_connect(button, "leave-event", G_CALLBACK(on_leave_event), NULL);
+	g_signal_connect(button, "notify::ancestor-interacting", G_CALLBACK(on_notify_ancestor_interacting), NULL);
 }
