@@ -32,8 +32,4 @@ typedef struct _TangleObjectClass {
 
 GType tangle_object_get_type(void) G_GNUC_CONST;
 
-gchar* tangle_object_lookup_filename(TangleObject* object, const gchar* filename);
-ClutterScript* tangle_object_get_script(TangleObject* object);
-void _tangle_object_set_script(TangleObject* object, ClutterScript* script);
-
 #endif
